Learn R Programming

rbiouml (version 1.11)

biouml.login: Login to BioUML server

Description

Login to BioUML server. The connection will be saved in global options under name biouml_connection for future reuse.

Usage

biouml.login(url='http://localhost:8080/biouml', user='', pass='')

Arguments

url

URL of running biouml server

user

BioUML user, empty string for anonymous login

pass

password

Value

Invisible connection to BioUML server, connection is a list with following items:

user

the name of user used for connection

pass

password in plain text

url

URL of biouml server

sessionId

session id returned by BioUML server

Examples

Run this code
# NOT RUN {
## connect to public BioUML server at https://ict.biouml.org
biouml.login("https://ict.biouml.org")
getOption("biouml_connection")
biouml.logout()
# }

Run the code above in your browser using DataLab