biouml.ls lists children data elements by path in BioUML repository
Usage
biouml.ls(path, extended=F)
Arguments
path
Path to data collection in BioUML repository
extended
whether to return additional attributes for each children
Value
If extended is FALSE a character vector with child names, otherwise a data frame (data.frame) with row.names corresponding to child names and columns hasChildren and type.