powered by
Login to BioUML server. The connection will be saved in global options under name biouml_connection for future reuse.
biouml.login(url='http://localhost:8080/biouml', user='', pass='')
URL of running biouml server
BioUML user, empty string for anonymous login
password
Invisible connection to BioUML server, connection is a list with following items:
the name of user used for connection
password in plain text
URL of biouml server
session id returned by BioUML server
# NOT RUN { ## connect to public BioUML server at https://ict.biouml.org biouml.login("https://ict.biouml.org") getOption("biouml_connection") biouml.logout() # }
Run the code above in your browser using DataLab